<?php

namespace Drupal\ada_accessible_helper_menu\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Admin form to configurable ADA Accessibility menu.
 */
class ADASettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'ada_accessible_helper_menu_admin_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['ada_accessible_helper_menu.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('ada_accessible_helper_menu.settings');

    $activeColor = $config->get('ada_active_color') ?? '#f15a22';
    $bg_color = $config->get('ada_bg_color') ?? '#cccccc';
    $textview = $config->get('ada_text_view') ?? 'Yes';
    $highcontrastview = $config->get('ada_high_contrast_view') ?? 'Yes';

    $options = [
      'Yes' => $this->t('Yes'),
      'No' => $this->t('No'),
    ];

    $form['Views'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Views'),
      '#collapsible' => TRUE,
    ];

    $form['Color'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Color'),
      '#collapsible' => TRUE,
    ];

    $form['Views']['ada_text_view'] = [
      '#type' => 'radios',
      '#title' => $this->t('Text View'),
      '#options' => $options,
      '#description' => $this->t('Enable Text View'),
      '#default_value' => $textview,
    ];

    $form['Views']['ada_high_contrast_view'] = [
      '#type' => 'radios',
      '#title' => $this->t('High Contrast View'),
      '#options' => $options,
      '#description' => $this->t('Enable High Contrast View'),
      '#default_value' => $highcontrastview,
    ];

    $form['Color']['ada_active_color'] = [
      '#title' => $this->t('Active Color'),
      '#type' => 'textfield',
      '#description' => $this->t('Enter Hashcode for as active highlight color of Button/icon'),
      '#default_value' => $activeColor,
      '#size' => 25,
      '#maxlength' => 25,
      '#required' => TRUE,
    ];

    $form['Color']['ada_bg_color'] = [
      '#title' => $this->t('Background Color'),
      '#type' => 'textfield',
      '#description' => $this->t('Enter Hashcode for background color of ada menu'),
      '#default_value' => $bg_color,
      '#size' => 25,
      '#maxlength' => 25,
      '#required' => TRUE,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Save the configuration values.
    parent::submitForm($form, $form_state);

    // Set the cookie with the updated values.
    $cookie_lifetime = time() + 365 * 24 * 60 * 60;
    setcookie('ada_Setting', json_encode([
      'ada_active_color' => $form_state->getValue('ada_active_color'),
      'ada_bg_color' => $form_state->getValue('ada_bg_color'),
      'ada_text_view' => $form_state->getValue('ada_text_view'),
      'ada_high_contrast_view' => $form_state->getValue('ada_high_contrast_view'),
    ]), $cookie_lifetime, '/');
  }

}
